/*
 * fb_parser.c -  parser for MySocials driver
 * This file is part of MSA program
 *
 * Copyright (C) 2009, 2010, 2011 - MySocials team
 *
 * MSA program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MSA program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MSA program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 */
#include "parser.h"


/*
 * Parse back url
 *
 * @param inner_req - inner request
 * @param cp - profile
 * @param data - redirect url from server
 * @param data_size - size of url
 * @param response - response in xml
 * @return 0 if login success, 1 if login failure
 */
#ifdef NOT_USE_DEFAULT_WEBAUTH_PARSER
int webauth_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response)
{
    gchar *begin, *end;
    MSA_UNUSED(inner_req)
    MSA_UNUSED(cp)
    MSA_UNUSED(data_size)
    if (data == NULL) {
        *response = g_strdup(MSG_AUTH_ERROR);
        return 1;
    }

    msa_debug("Received from webauth : %s", data);

    if (strstr(data, "access_denied") || g_strcmp0(data, "closed") == 0) {
        *response = g_strdup(MSG_AUTH_CANCEL);
        return 1;
    }

    begin = strstr(data, "access_token=");
    if (!begin) {
        *response = g_strdup(MSG_AUTH_ERROR);
        return 1;
    }
    while(*begin != '=' && *begin != '\0')
        ++begin;
    if (*begin == '\0') {
        *response = g_strdup(MSG_AUTH_ERROR);
        return 1;
    }
    ++begin;
    end = strstr(begin, "&");
    if (end)
        *end='\0';
    *response = g_strconcat("<?xml version=\"1.0\"?><response><sid>",
                            begin, "</sid></response>", NULL);
    return 0;
}
#endif


/**
 * Parses json data
 *
 * @param json - data in json format
 * @return 0 - on success, 1 other
 */
#ifdef NOT_USE_DEFAULT_JSON_PARSER
int json_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response)
{
    struct json_object *buf = NULL;
    gchar* resp_str = NULL;
    gchar* tmp_str = NULL;
    char *key; struct json_object *val; struct lh_entry *entry;
    char *ekey; struct json_object *eval; struct lh_entry *eentry;
    MSA_UNUSED(inner_req)
    MSA_UNUSED(cp)
    MSA_UNUSED(data_size)

    if(data != NULL) {
        buf = json_tokener_parse(data);
        if(buf != NULL) {
            if (is_error(buf)){
                *response = NULL;
                return 1;
            }
            tmp_str = g_strconcat("<?xml version=\"1.0\" encoding=\"UTF-8\"?>", "<response>", NULL);

            for(entry = json_object_get_object(buf)->head; (entry ? (key = (char*)entry->k, val = (struct json_object*)entry->v, entry) : 0); entry = entry->next)  {
                if (g_strcmp0((gchar*)key,"error")==0) {
                    resp_str = g_strconcat(tmp_str, "<error>", NULL);
                    g_free(tmp_str);
                    tmp_str = resp_str;
                    for(eentry = json_object_get_object(val)->head; (eentry ? (ekey = (char*)eentry->k, eval = (struct json_object*)eentry->v, eentry) : 0); eentry = eentry->next)  {
                        resp_str = g_strconcat(tmp_str, "<", ekey, ">",
                                                        json_object_get_string(eval),
                                                        "</",ekey, ">", NULL);
                        g_free(tmp_str);
                        tmp_str = resp_str;
                    }
                    resp_str = g_strconcat(tmp_str, "</error>", NULL);
                    g_free(tmp_str);
                    tmp_str = resp_str;
                } else {
                    resp_str = g_strconcat(tmp_str, "<", key, ">",
                                                    json_object_get_string(val),
                                                    "</",key, ">", NULL);
                    g_free(tmp_str);
                    tmp_str = resp_str;
                }
                
            }
            resp_str = g_strconcat(tmp_str, "</response>", NULL);
            g_free(tmp_str);
            *response = resp_str;
            json_object_put(buf);
            return 0;
         } 

    }
    *response = NULL;
    return 1;
}
#endif

